@@ -3,13 +3,16 @@ from __future__ import unicode_literals
 
 import logging
 import os
-import time
+import threading
 import tempfile
 import pytest
 import xml.etree.ElementTree as ET
 import pickle
+import time
+
 
 from boardgamegeek import BoardGameGeek, BoardGameGeekError
+from boardgamegeek.api import BoardGameGeekNetworkAPI
 from boardgamegeek.collection import Collection
 from boardgamegeek.games import CollectionBoardGame
 from boardgamegeek.hotitems import HotItems, HotItem
@@ -23,6 +26,7 @@ import datetime
 
 progress_called = False
 
+
 # Kinda hard to test without having a "test" user
 TEST_VALID_USER = "fagentu007"
 TEST_VALID_USER_ID = 818216
@@ -33,6 +37,8 @@ TEST_INVALID_GAME_NAME = "blablablathisgamewonteverexist"
 TEST_GAME_NAME = "Agricola"
 TEST_GAME_ID = 31260
 
+
+
 #TEST_GAME_NAME_2 = "Merchant of Venus (second edition)"
 #TEST_GAME_ID_2 = 131646
 
@@ -44,14 +50,11 @@ TEST_GUILD_ID_2 = 930
 
 
 if os.getenv("TRAVIS"):
-    TEST_SLEEP_DELAY = 15   # when running on travis I still get tests failing despite the delay. Attempting to compensate.
     logging.basicConfig(level=logging.DEBUG)
 else:
-    TEST_SLEEP_DELAY = 10
     logging.basicConfig(level=logging.INFO)
 
 
-
 @pytest.fixture
 def xml():
     xml_code = """
@@ -73,7 +76,7 @@ def xml():
 
 @pytest.fixture
 def bgg():
-    return BoardGameGeek()
+    return BoardGameGeek(cache=None, retries=0, retry_delay=0)  # disable retrying for testing
 
 @pytest.fixture
 def null_logger():
@@ -93,8 +96,6 @@ def progress_cb(items, total):
 # Test caches
 #
 def test_no_caching():
-    time.sleep(10)
-
     # test that we can disable caching
     bgg = BoardGameGeek(cache=None)
 
@@ -105,8 +106,6 @@ def test_no_caching():
 
 
 def test_sqlite_caching():
-    time.sleep(TEST_SLEEP_DELAY)
-
     # test that we can use the SQLite cache
     # generate a temporary file
     fd, name = tempfile.mkstemp(suffix=".cache")
@@ -121,6 +120,9 @@ def test_sqlite_caching():
         # invalid value for the ttl parameter
         BoardGameGeek(cache="sqlite://{}?ttl=blabla&fast_save=0".format(name))
 
+    with pytest.raises(BoardGameGeekError):
+        BoardGameGeek(cache="invalid://cache")
+
     bgg = BoardGameGeek(cache="sqlite://{}?ttl=1000".format(name))
 
     user = bgg.user(TEST_VALID_USER)
@@ -133,6 +135,7 @@ def test_sqlite_caching():
     os.unlink(name)
 
 
+
 #region user() testing
 def test_get_user_with_invalid_parameters(bgg):
     # test how the module reacts to unexpected parameters
@@ -142,7 +145,6 @@ def test_get_user_with_invalid_parameters(bgg):
 
 
 def test_get_invalid_user_info(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
 
     global progress_called
 
@@ -154,8 +156,6 @@ def test_get_invalid_user_info(bgg):
 
 
 def test_get_valid_user_info(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     global progress_called
 
     progress_called = False
@@ -203,14 +203,11 @@ def test_get_collection_with_invalid_parameters(bgg):
 
 
 def test_get_invalid_users_collection(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
     collection = bgg.collection(TEST_INVALID_USER)
     assert collection is None
 
 
 def test_get_valid_users_collection(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     collection = bgg.collection(TEST_VALID_USER)
 
     assert collection is not None
@@ -261,8 +258,6 @@ def test_get_guild_with_invalid_parameters(bgg):
 
 
 def test_get_valid_guild_info(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     global progress_called
 
     progress_called = False
@@ -298,8 +293,6 @@ def test_get_valid_guild_info(bgg, null_logger):
 
 
 def test_get_invalid_guild_info(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
-
     global progress_called
 
     progress_called = False
@@ -312,8 +305,6 @@ def test_get_invalid_guild_info(bgg):
 
 #region game() testing
 def test_get_unknown_game_info(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
-
     game = bgg.game(TEST_INVALID_GAME_NAME)
     assert game is None
 
@@ -332,8 +323,6 @@ def test_get_game_with_invalid_parameters(bgg):
 
 
 def check_game(game):
-    time.sleep(TEST_SLEEP_DELAY)
-
     assert game is not None
     assert game.name == TEST_GAME_NAME
     assert game.id == TEST_GAME_ID
@@ -341,38 +330,23 @@ def check_game(game):
     assert game.mechanics == ["Area Enclosure", "Card Drafting", "Hand Management", "Worker Placement"]
     assert game.min_players == 1
     assert game.max_players == 5
-    assert "cf.geekdo-images.com/images/pic259085_t.jpg" in game.thumbnail
-    assert "cf.geekdo-images.com/images/pic259085.jpg" in game.image
-    assert game.playing_time == 120
+    assert game.thumbnail == "http://cf.geekdo-images.com/images/pic259085_t.jpg"
+    assert game.image == "http://cf.geekdo-images.com/images/pic259085.jpg"
+    assert game.playing_time > 100
     assert game.min_age == 12
-    assert game.categories == ["Economic", "Farming"]
+
+    assert "Economic" in game.categories
+    assert "Farming" in game.categories
 
     assert game.families == ["Agricola", "Animals: Cattle", "Animals: Sheep", "Harvest Series", "Solitaire Games"]
 
     assert game.designers == ["Uwe Rosenberg"]
 
-    assert game.publishers == ["Lookout Games",
-                               "999 Games",
-                               "Brain Games",
-                               "Compaya.hu - Gamer Café Kft.",
-                               "Filosofia Édition",
-                               "Hobby Japan",
-                               "Hobby World",
-                               "HomoLudicus",
-                               "Korea Boardgames co., Ltd.",
-                               "Lacerta",
-                               "MINDOK",
-                               "Smart Ltd",
-                               "Stratelibri",
-                               "Swan Panasia Co., Ltd.",
-                               "Ystari Games",
-                               "Z-Man Games"]
+    assert "Lookout Games" in game.publishers
+    assert "Compaya.hu - Gamer Café Kft." in game.publishers
 
-    assert game.alternative_names == ["Агрикола",
-                                      "アグリコラ",
-                                      "农场主",
-                                      "農家樂",
-                                      "아그리콜라"]
+    assert u"Агрикола" in game.alternative_names
+    assert u"아그리콜라" in game.alternative_names
 
     # some not so exact assertions
     assert game.users_rated >= 34000
@@ -384,13 +358,13 @@ def check_game(game):
     assert game.rating_num_weights >= 0
     assert type(game.rating_average_weight) == float
 
+    assert type(game.boardgame_rank) == int
+
     # make sure no exception gets thrown
     repr(game)
 
 
 def test_get_known_game_info(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     # use an older game that's not so likely to change
     game = bgg.game(TEST_GAME_NAME)
 
@@ -403,22 +377,39 @@ def test_get_known_game_info(bgg, null_logger):
 
 
 def test_get_known_game_info_by_id(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
-
     game = bgg.game(None, game_id=TEST_GAME_ID)
     check_game(game)
 
 
 def test_get_game_id_by_name(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
-
     game_id = bgg.get_game_id(TEST_GAME_NAME)
     assert game_id == TEST_GAME_ID
 
+    # Use the game "Eclipse" to test the game choosing methods
+    all_eclipse_games = bgg.games("eclipse")
+
+    game_id = bgg.get_game_id("eclipse", choose="first")
+    assert game_id == all_eclipse_games[0].id
+
+    game_id = bgg.get_game_id("eclipse", choose="recent")
+    recent_year = -100000
+    recent_id = None
+    for g in all_eclipse_games:
+        if g.year > recent_year:
+            recent_id = g.id
+            recent_year = g.year
+    assert game_id == recent_id
+
+    game_id = bgg.get_game_id("eclipse", choose="best-rank")
+    best_rank = 1000000000
+    best_id = None
+    for g in all_eclipse_games:
+        if g.boardgame_rank is not None and g.boardgame_rank < best_rank:
+            best_id = g.id
+            best_rank = g.boardgame_rank
+    assert game_id == best_id
 
 def test_get_games_by_name(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     games = bgg.games("coup")
 
     for g in games:
@@ -430,6 +421,25 @@ def test_get_games_by_name(bgg, null_logger):
     assert len(games) > 1
 #endregion
 
+#region search() testing
+def test_search(bgg):
+    res = bgg.search("some invalid game name", exact=True)
+    assert not len(res)
+
+    res = bgg.search("Twilight Struggle", exact=True)
+    assert len(res)
+
+    # test that numeric searching still works
+    res = bgg.search("Agricola", search_type=BoardGameGeekNetworkAPI.SEARCH_BOARD_GAME)
+    assert type(res[0].id) == int
+
+    # test that the new type of search works
+    res = bgg.search("Agricola", search_type=["boardgame"])
+    assert type(res[0].id) == int
+
+    with pytest.raises(BoardGameGeekError):
+        bgg.search("Agricola", search_type=["invalid-search-type"])
+#endregion
 
 #region plays() testing
 def test_get_plays_with_invalid_parameters(bgg):
@@ -444,8 +454,6 @@ def test_get_plays_with_invalid_parameters(bgg):
 
 
 def test_get_plays_with_unknown_username_and_id(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
-
     plays = bgg.plays(name=TEST_INVALID_USER)
     assert plays is None
 
@@ -455,8 +463,6 @@ def test_get_plays_with_unknown_username_and_id(bgg):
 
 
 def test_get_plays_with_invalid_dates(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
-
     # A string is invalid so should raise an error
     with pytest.raises(BoardGameGeekError):
         bgg.plays(name=TEST_VALID_USER, min_date="2014-01-01")
@@ -466,8 +472,6 @@ def test_get_plays_with_invalid_dates(bgg):
 
 
 def test_get_plays_with_valid_dates(bgg):
-    time.sleep(TEST_SLEEP_DELAY)
-
     min_date = datetime.date(2014, 1, 1)
     max_date = datetime.date(2014, 12, 31)
     plays = bgg.plays(TEST_VALID_USER, min_date=min_date, max_date=max_date)
@@ -475,8 +479,6 @@ def test_get_plays_with_valid_dates(bgg):
 
 
 def test_get_plays_of_user(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     global progress_called
 
     plays = bgg.plays(name=TEST_VALID_USER, progress=progress_cb)
@@ -491,7 +493,7 @@ def test_get_plays_of_user(bgg, null_logger):
         assert type(p.date) == datetime.datetime
         assert p.quantity >= 0
         assert p.duration >= 0
-        assert type(p.incomplete) == int
+        assert type(p.incomplete) == bool
         assert type(p.nowinstats) == int
         assert type(p.game_id) == int
         assert type(p.game_name) == str
@@ -513,8 +515,6 @@ def test_get_plays_of_user(bgg, null_logger):
 
 
 def test_get_plays_of_game(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     global progress_called
 
     plays = bgg.plays(game_id=TEST_GAME_ID_2, progress=progress_cb)
@@ -529,7 +529,7 @@ def test_get_plays_of_game(bgg, null_logger):
         assert type(p.date) in [datetime.datetime, type(None)]
         assert p.quantity >= 0
         assert p.duration >= 0
-        assert type(p.incomplete) == int
+        assert type(p.incomplete) == bool
         assert type(p.nowinstats) == int
         assert p.game_id == TEST_GAME_ID_2
         assert p.game_name == TEST_GAME_NAME_2
@@ -565,19 +565,18 @@ def test_get_hot_items_invalid_type(bgg):
 
 
 def test_get_hot_items_boardgames(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     for item in bgg.hot_items("boardgame"):
         assert type(item.id) == int
         assert len(item.name) > 0
         assert type(item.rank) == int
         assert type(item.year) in [int, type(None)]
+        # test that all thumbnails have been fixed (http:// added)
+        # note: I guess this could fail if a boardgame has no thumbnail...
+        assert item.thumbnail.startswith("http://")
         item._format(null_logger)
 
 
 def test_get_hot_items_boardgamepersons(bgg, null_logger):
-    time.sleep(TEST_SLEEP_DELAY)
-
     for item in bgg.hot_items("boardgameperson"):
         assert type(item.id) == int
         assert len(item.name) > 0
@@ -732,3 +731,59 @@ def test_serialization():
 
     dummy_unserialized = pickle.loads(s)
     assert type(dummy_unserialized) == Thing
+
+
+def test_rate_limiting_for_requests():
+    # create two threads, give each a list of games to fetch, disable cache and time the amount needed to
+    # fetch the data. requests should be serialized, even if made from two different threads
+
+    test_set_1 = [5,    # acquire
+                  31260, # agricola
+                  72125] # "eclipse"
+
+    test_set_2 = [18602, #caylus
+                28720, #  brass
+                53953] # thunderstone]
+
+    def _worker_thread(games):
+        bgg = BoardGameGeek(cache=None, requests_per_minute=20)
+        for g in games:
+            bgg.game(game_id=g)
+
+    t1 = threading.Thread(target=_worker_thread, args=(test_set_1, ))
+    t2 = threading.Thread(target=_worker_thread, args=(test_set_2, ))
+
+    start_time = time.time()
+    t1.start()
+    t2.start()
+
+    t1.join(timeout=10000)
+    t2.join(timeout=10000)
+    end_time = time.time()
+
+    # 20 requests per minute => a request every 3 seconds x 6 games => should take around 18 seconds
+    assert 15 < end_time - start_time < 21      # +/- a few seconds...
+
+
+    # second test, use caching and confirm it's working when combined with the rate limiting algorithm
+    # do cached requests for the test set, then do them again. should take only half of the time
+
+    bgg = BoardGameGeek(requests_per_minute=20)
+
+    start_time = time.time()
+    for g in test_set_1:
+        bgg.game(game_id=g)
+    end_time = time.time()
+
+    assert 7 < end_time - start_time < 11       # 3 games should take ~9 seconds
+
+    # repeat requests, should be served from cache
+    for g in test_set_1:
+        bgg.game(game_id=g)
+
+    assert 0 < time.time() - end_time < 2
+
+
+if __name__ == "__main__":
+    logging.basicConfig(level=logging.DEBUG)
+    test_rate_limiting_for_requests()
